Installation
============

Installation of vspk
++++++++++++++++++++

To install `vspk`, run the following command:

.. code-block:: bash
    :linenos:

    pip install vspk


Installation of vsdcli
++++++++++++++++++++++

We also provide a command line interface named `vsd` that allows to interact with a VSD Server. This command uses introspection on the `vspk` and will work with all API versions supported by your current `vspk` installation. By updating the `vspk`, the cli will be automagically up to date to.

To install `vsdcli`, run the following command:

.. code-block:: bash
    :linenos:

    pip install vsdcli
